@@ -483,7 +483,7 @@ int get_COcore_mass(int index_of_the_star, double * mass){
 
 
 int change_mass(int index_of_the_star, double mass, double dt){
-    cout << "Enter change mass:"<< mass<< " "<< dt<<endl;
+//    cout << "Enter change mass:"<< mass<< " "<< dt<<endl;
     int error_code = 0;
     node * seba_node = get_seba_node_from_index(index_of_the_star, &error_code);
     if(error_code < 0) {return error_code;}
@@ -494,7 +494,7 @@ int change_mass(int index_of_the_star, double mass, double dt){
     else {
       mass *= -1;
       star *star = seba_node->get_starbase()->subtrac_mass_from_donor(dt, mass);
-      PRL(star);
+//      PRL(star);
     }
     return error_code;
 }
